using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using EFB.Sessions;
using Microsoft.Extensions.Logging;
using EFB.Models;
using EFB.MongoData;

namespace EFB.Controllers
{
    //[Route("[controller]")]
    public class FlightsimController : Controller
    {
        private readonly ILogger<FlightsimController> _logger;

        public FlightsimController(ILogger<FlightsimController> logger)
        {
            _logger = logger;
        }

        public async Task<IActionResult> Index()
        {
            //Retrieve and Check current user status
            UserModel user = HttpContext.Session.GetObject<UserModel>("User");
            if(user == null) return RedirectToAction("Index", "Home");

            //Retrieve the user's latest sim position and construct it into FlightsimModel
            if (user.Route == null) return RedirectToAction("Index", "Route");

            SimPositionModel latestPosition = await Mongo.GetLatestData(user.EMail);
            RouteModel route = await RouteModel.StringToRoute(user.Departure, user.Arrival, user.Cruise, user.Route);

            return View(new FlightsimModel(latestPosition, null));

        }

        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View("Error!");
        }
    }
}